/*
 * Demonstrates how to use the Bing Search web service API
 * and then parsing the JSON format results.
 * 
 * You need a Bing developer username and app ID key in
 * order to use the web service.
 * 
 * Created by Keith Vertanen
 */

import org.json.*;
import java.io.*;
import java.net.*;

public class BingSearch
{
    public static void main(String[] args)
    {
        if (args.length < 3)
        {
            System.out.println("BingSearch <userID> <appID> <query>");
            return;
        }
        
        String userID = args[0];
        String appID  = args[1];
        String query  = args[2];
        
        try
        {
            String page = "https://";
            page += "api.datamarket.azure.com/Bing/Search/Web?";
            page += "Query=%27" + URLEncoder.encode(query, "UTF-8") + "%27";
            page += "&$format=json";

            // Create the HTTP basic authentication credentials
            String auth = userID + ":" + appID;
            byte [] bytes = auth.getBytes();            
            String accountKeyEnc = Base64.encodeBytes(bytes);
            
            URL               url    = new URL(page);
            URLConnection     conn   = url.openConnection();
            conn.setRequestProperty("Authorization", "Basic " + accountKeyEnc);
            
            InputStreamReader stream = new InputStreamReader(conn.getInputStream());
            BufferedReader    reader = new BufferedReader(stream);
                        
            // Read in all the entire HTTP response
            String line     = "";
            String response = "";    
            do
            {
               line = reader.readLine();
               if (line != null)
                  response += line + "\n";
            }
            while (line != null);
            reader.close();

            // Print out the raw JSON data received from Bing
            System.out.println(response);
            
            // Parse the JSON 
            JSONObject json = new JSONObject(response);

            // Descend to the actual array of web search results
            JSONObject  d       = json.getJSONObject("d");            
            JSONArray   results = d.getJSONArray("results");
            JSONObject  result  = results.getJSONObject(0);            
            JSONArray   web     = result.getJSONArray("Web");
            
            // Loop over the results printing out the page title and URL
            for (int i = 0; i < web.length(); i++)
            {
                JSONObject hit = web.getJSONObject(i);
                System.out.printf("%d : %s, %s\n", 
                                    i, 
                                    hit.getString("Title"),
                                    hit.getString("Url"));
            }
        }
        catch (MalformedURLException e) 
        { 
            e.printStackTrace(); 
        }
        catch (IOException e)           
        { 
           e.printStackTrace(); 
        }
    }

}
